===========
LAMMPS step
===========


.. image:: https://img.shields.io/travis/molssi-seamm/lammps_step.svg
           :target: https://travis-ci.org/molssi-seamm/lammps_step
	   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/lammps_step/branch/master/graph/badge.svg
	   :target: https://codecov.io/gh/molssi-seamm/lammps_step
	   :alt: Code Coverage

.. image:: https://img.shields.io/lgtm/grade/python/g/molssi-seamm/lammps_step.svg?logo=lgtm&logoWidth=18
	   :target: https://lgtm.com/projects/g/molssi-seamm/lammps_step/context:python
	   :alt: Code Quality

.. image:: https://readthedocs.org/projects/lammps-step/badge/?version=latest
           :target: https://lammps-step.readthedocs.io/en/latest/?badge=latest
	   :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/lammps_step/shield.svg
	   :target: https://pyup.io/repos/github/molssi-seamm/lammps_step/
	   :alt: Updates for Dependencies

.. image:: https://img.shields.io/pypi/v/lammps_step.svg
           :target: https://pypi.python.org/pypi/lammps_step
	   :alt: PyPi VERSION

The LAMMPS step for a SEAMM flowchart


* Free software: BSD license
* Documentation: https://lammps-step.readthedocs.io.


Contributing
------------

Creating a feature branch 
~~~~~~~~~~~~~~~~~~~~~~~~~~

When starting work on a new feature, branch off from the develop branch::

  $ git checkout -b myfeature
  Switched to a new branch "myfeature"

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `molssi-seamm/cookiecutter-seamm-plugin`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`molssi-seamm/cookiecutter-seamm-plugin`: https://github.com/molssi-seamm/cookiecutter-seamm-plugin

Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the `National Science Foundation`_ under
award ACI-1547580

.. _MolSSI: https://www.molssi.org
.. _`National Science Foundation`: https://www.nsf.gov
